@@ -13,6 +13,7 @@ from zipfile import is_zipfile
 from pathlib import Path as _Path
 import warnings
 import os
+import shutil
 
 
 def get_parent_directory(path):
@@ -25,12 +26,54 @@ class Path:
 		:type string: str or Path
 		:type show_size: bool
 		"""
+		string = string or '.'
+
 		if isinstance(string, self.__class__) or not isinstance(string, str):
 			string = string.path
 		self._string = string
 		self._size = None
 		self._show_size = show_size
 
+	def rename(self, new_name):
+		"""
+		:type new_name: str or Path
+		:rtype: Path
+		"""
+		if isinstance(new_name, Path):
+			new_name = new_name.name_and_extension
+
+		shutil.move(self.absolute_path, (self.parent_directory + new_name).absolute_path)
+		self._string = self._string[:-len(self.name_and_extension)] + new_name
+		return self
+
+	def move(self, new_directory):
+		"""
+		:type new_directory: str or Path
+		:rtype: Path
+		"""
+		new_directory = Path(new_directory)
+		if not new_directory.exists():
+			new_directory.make_dir()
+		new_path = (new_directory + self.name_and_extension)
+		shutil.move(self.absolute_path, new_path.absolute_path)
+		self._string = new_path.absolute_path
+		return self
+
+	def copy(self, new_path):
+		"""
+		:type new_path str or Path
+		:rtype: Path
+		"""
+		if not self.exists():
+			raise FileExistsError(f'{self} does not exist!')
+
+		new_path = Path(new_path)
+		if new_path.exists() and new_path.is_directory() and self.is_file():
+			new_path = new_path + self.name_and_extension
+
+		shutil.copy2(self.path, new_path.path)
+		return new_path
+
 	def __str__(self):
 		return self.__repr__()
 
@@ -91,12 +134,26 @@ class Path:
 		"""
 		return cls(string='.', show_size=show_size)
 
+	def get_parent_directory(self, absolute=False):
+		"""
+		:type absolute: bool
+		:rtype: Path
+		"""
+		if absolute:
+			return self.__class__(string=get_parent_directory(self.absolute_path))
+		else:
+			string_except_name_and_extension = self._string[:-len(self.name_and_extension)]
+			if len(string_except_name_and_extension) > 0:
+				return self.__class__(string=string_except_name_and_extension)
+			else:
+				return self.get_current_directory(show_size=self._show_size)
+
 	@property
 	def parent_directory(self):
 		"""
 		:rtype: Path
 		"""
-		return self.__class__(string=get_parent_directory(self.absolute_path))
+		return self.get_parent_directory(absolute=False)
 
 	def __parents__(self):
 		"""
